@@ -7,11 +7,15 @@
 #ifndef WINDOWSHADOW_H
 #define WINDOWSHADOW_H
 
-#include <KWayland/Client/buffer.h>
-#include <KWayland/Client/shadow.h>
 #include <private/kwindowshadow_p.h>
 
-class WindowShadowTile final : public KWindowShadowTilePrivate
+#include <memory>
+
+class Shadow;
+class ShmBuffer;
+class Shm;
+
+class WindowShadowTile final : public QObject, public KWindowShadowTilePrivate
 {
 public:
     WindowShadowTile();
@@ -22,13 +26,14 @@ public:
 
     static WindowShadowTile *get(const KWindowShadowTile *tile);
 
-    KWayland::Client::Buffer::Ptr buffer;
-    QScopedPointer<KWayland::Client::ShmPool> m_shmPool;
+    std::unique_ptr<ShmBuffer> buffer;
 };
 
 class WindowShadow final : public QObject, public KWindowShadowPrivate
 {
 public:
+    WindowShadow();
+    ~WindowShadow() override;
     bool create() override;
     void destroy() override;
 
@@ -39,7 +44,7 @@ private:
     bool internalCreate();
     void internalDestroy();
 
-    QPointer<KWayland::Client::Shadow> shadow;
+    std::unique_ptr<Shadow> shadow;
 };
 
 #endif // WINDOWSHADOW_H
